; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "BurningImpulse"
command = ~F, DF, D, DB, B, F, DF, D, DB, B, ab
time = 40

[Command]
name = "KotobukiSlam"
command = ~D, DF, F, D, DF, F, x
time = 40

[Command]
name = "KotobukiSlam"
command = ~D, DF, F, D, DF, F, y
time = 40

[Command]
name = "BurningLegLariat"
command = ~D, DB, B, D, DB, B, a
time = 40

[Command]
name = "BurningLegLariat"
command = ~D, DB, B, D, DB, B, b
time = 40

[Command]
name = "FinalKotobukiBuster"
command = ~F, DF, D, DB, B, F, DF, D, DB, B, x
time = 40

[Command]
name = "FinalKotobukiBuster"   ;Same name as above
command = ~F, DF, D, DB, B, F, DF, D, DB, B, y
time = 40


;-| Special Motions |------------------------------------------------------
[Command]
name = "HCBF_x"
command = ~F, DF, D, DB, B, F, x
time = 20

[Command]
name = "HCBF_y"
command = ~F, DF, D, DB, B, F, y
time = 20

[Command]
name = "FDF_x"
command = ~F, DF, D, DF, F, x

[Command]
name = "FDF_y"
command = ~F, DF, D, DF, F, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "HCF_a"
command = ~B, DB, D, DF, F, a

[Command]
name = "HCF_b"
command = ~B, DB, D, DF, F, b

[Command]
name = "QCB_ab"
command = ~D, DB, B, a+b

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = z
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "hold_ab";Required (do not remove)
command = /~200a
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
[State -2, Call Memorizer Helper]
type = Helper
trigger1 = !NumHelper(161616)
trigger1 = AILevel
name = "Memory"
stateno = 161616
ID = 161616
size.xscale = 1
size.yscale = 1
postype = p1
pos = -9999,-9999
ownpal = 1
supermovetime = 9999**2
pausemovetime = 9999**2
ignorehitpause = 1
;Notes
;StateNo=5020 necessary for OTG hits
;Important Routes to implement
;440 > 1030 || 1040
;210 > Buki Buster > 440 > 3030
[State -1, Read Memorized Attacks]
Type = null
ignorehitpause = 1
triggerall = ailevel
triggerall = p2movetype != A
trigger1 = var(51) := 0
trigger2 = var(50) := 0

[State -1, Read Memorized Attacks]
Type = Null
ignorehitpause = 1
triggerall = ailevel
Triggerall = NumHelper(161616)
triggerall = p2movetype = A
trigger1 = helper(161616),var(1) = enemynear,stateno
trigger1 = var(51) := helper(161616),var(1) 
trigger1 = var(50) := helper(161616),var(8)
trigger2 = helper(161616),var(2) = enemynear,stateno
trigger2 = var(51) := helper(161616),var(2) 
trigger2 = var(50) := helper(161616),var(9)
trigger3 = helper(161616),var(3) = enemynear,stateno
trigger3 = var(51) := helper(161616),var(3) 
trigger3 = var(50) := helper(161616),var(10)
trigger4 = helper(161616),var(4) = enemynear,stateno
trigger4 = var(51) := helper(161616),var(4) 
trigger4 = var(50) := helper(161616),var(11)
trigger5 = helper(161616),var(5) = enemynear,stateno
trigger5 = var(51) := helper(161616),var(5) 
trigger5 = var(50) := helper(161616),var(12)
trigger6 = helper(161616),var(6) = enemynear,stateno
trigger6 = var(51) := helper(161616),var(6) 
trigger6 = var(50) := helper(161616),var(13)
trigger7 = helper(161616),var(7) = enemynear,stateno
trigger7 = var(51) := helper(161616),var(7) 
trigger7 = var(50) := helper(161616),var(14)
trigger8 = helper(161616),var(15) = enemynear,stateno
trigger8 = var(51) := helper(161616),var(15) 
trigger8 = var(50) := helper(161616),var(22)
trigger9 = helper(161616),var(16) = enemynear,stateno
trigger9 = var(51) := helper(161616),var(16) 
trigger9 = var(50) := helper(161616),var(23)
trigger10 = helper(161616),var(17) = enemynear,stateno
trigger10 = var(51) := helper(161616),var(17) 
trigger10 = var(50) := helper(161616),var(24)
trigger11 = helper(161616),var(18) = enemynear,stateno
trigger11 = var(51) := helper(161616),var(18) 
trigger11 = var(50) := helper(161616),var(25)
trigger12 = helper(161616),var(19) = enemynear,stateno
trigger12 = var(51) := helper(161616),var(19) 
trigger12 = var(50) := helper(161616),var(26)
trigger13 = helper(161616),var(20) = enemynear,stateno
trigger13 = var(51) := helper(161616),var(20) 
trigger13 = var(50) := helper(161616),var(27)
trigger14 = helper(161616),var(21) = enemynear,stateno
trigger14 = var(51) := helper(161616),var(21) 
trigger14 = var(50) := helper(161616),var(28)


[state -1, Checks]
Type = VarSet
ignorehitpause = 1
TriggerAll = ailevel
Trigger1 = !InGuardDist
;Triggers Below Reserved for Specific States
var(54) = 0
[state -1, Checks]
Type = VarSet
ignorehitpause = 1
TriggerAll = ailevel
TriggerAll = P2MoveType = A
trigger1 = helper(161616),fvar(1) = enemynear,stateno
trigger2 = p2statetype = S
var(54) = 1
[state -1, Checks]
Type = VarSet
ignorehitpause = 1
TriggerAll = ailevel
TriggerAll = P2MoveType = A
trigger1 = helper(161616),fvar(0) = enemynear,stateno
trigger2 = p2statetype = C
var(54) = 2
[state -1, Checks]
Type = VarSet
ignorehitpause = 1
TriggerAll = ailevel
TriggerAll = P2MoveType = A
trigger1 = enemynear,pos y < 0
trigger1 = p2statetype = A
var(54) = 3
[state -1, Checks]
Type = VarSet
ignorehitpause = 1
TriggerAll = ailevel
TriggerAll = P2MoveType = A
trigger1 = helper(161616),fvar(2) = enemynear,stateno
trigger1 = statetype = A
var(54) = 4

[STate Combo Output Reset]
Type = VarSet
var(59) = 0
ignorehitpause = 1
triggerall = AILevel
trigger1 = !NumTarget
trigger2 = P2MoveType = I 

[State -1, Combo Output]
Type = Null
ignorehitpause = 1
TriggerAll = MoveType = A
triggerAll = NumTarget
TriggerAll = MoveHit = 1 || Target, Time = 1 && target,stateno != [120,159]
Trigger1 = StateNo = 440
trigger1 = var(59) := ifelse(p2stateno != 5020,9,1+(power>1000))
Trigger2 = anim = 1024
trigger2 = var(59) := 3
Trigger3 = StateNo = 210
trigger3 = Target,StateType != A
trigger3 = var(59) := ifelse(power>500&&var(3)<2&&random%2 = 1,21,4)
Trigger4 = StateNo = 210||stateno = 215&&time>13
trigger4 = Target,StateType = A
trigger4 = var(59) := 5+(4*(stateno = 210))
trigger5 = StateNo = [1100,1119]
trigger5 = var(59) := 6
trigger6 = StateNo = 810
trigger6 = var(59) := 8
trigger7 = StateNo = 1040
trigger7 = var(59) := 22
[State -1, Combo Output]
Type = Null
ignorehitpause = 1
TriggerAll = MoveType = A
triggerAll = NumTarget
TriggerAll = MoveGuarded = 1 || Target, Time = 1 && target,stateno = [120,159]
Trigger1 = StateNo = 440||stateno = 210
trigger1 = var(59) := 11 

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
FV = (39)
Trigger1 = fvar(39) = fvar(38)    ;AI only
Value = 0

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
FV = (38)
trigger1 = fvar(39) != 0
Value = fvar(39)


[state -1, Full AI Programming, PostMatch]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	(AILevel) && !fvar(39)    ;AI only
triggerall	=	Win   ;Only when fighting
triggerall	=	alive           ;Only when alive
trigger1	=	ctrl
trigger1	=	prevstateno != 195
trigger1	=	life > 400
trigger1	=	statetype != A
trigger1	=	fvar(39) := 195           ;Only when alive
[state -1, Full AI Programming, Reversal]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	(AILevel) && !fvar(39)    ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	alive           ;Only when alive
trigger1	=	power>1000
Trigger1	=	P2BodyDist Y>=const(size.head.pos.y)-50   ;vertical distance (non-anti-air situations)
Trigger1	=	P2BodyDist X<=130  ;Horizontal distance (maximum range)
Trigger1	=	StateType != A	;Set for appropriate StateType
Trigger1	=	stateno = 152 || stateno = 154                   ;while having control
trigger1	=	 (fvar(39) := 6070)

[state -1, Full AI Programming, Guard Punish]
Type = Null
IgnoreHitPause = 1
triggerall	=	numhelper(161616)
triggerall	=	var(51) 
triggerall	=	var(50) 
triggerall	=	enemynear,time>var(50)+8 
triggerall	=	!NumTarget         ;Not within guard distance
triggerall	=	numenemy
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	alive           ;Only when alive
TriggerAll	=	(AILevel) && !fvar(39)    ;AI only
triggerall	=	stateno != [120,159]
triggerall	=	ctrl
triggerall	=	p2bodydist x >= 0
trigger1	=	helper(161616),fvar(10) != 400;not blacklisted
trigger1	=	helper(161616),fvar(11) != 400;not blacklisted
trigger1	=	helper(161616),fvar(12) != 400;not blacklisted
trigger1	=	helper(161616),fvar(13) != 400;not blacklisted
trigger1	=	p2bodydist x < 2*25
trigger1	=	p2statetype != A
trigger1	=	 fvar(39) := 400

[state -1, Full AI Programming, Throw Specific]
Type = Null
IgnoreHitPause = 1
triggerall	=	 !fvar(39)    ;AI only
TriggerAll	=	(AILevel) 
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	numenemy
triggerall	=	alive           ;Only when alive
triggerall	=	!NumTarget
triggerall	=	ctrl
triggerall	=	statetype != A
triggerall	=	gametime%(12 - ailevel) = 1||ailevel > 6
trigger1	=	helper(161616),fvar(10) != 1020||p2movetype != A;not blacklisted
trigger1	=	helper(161616),fvar(11) != 1020||p2movetype != A;not blacklisted
trigger1	=	helper(161616),fvar(12) != 1020||p2movetype != A;not blacklisted
trigger1	=	helper(161616),fvar(13) != 1020||p2movetype != A;not blacklisted
trigger1	=	p2stateno != [5100,5299]
trigger1	=	enemynear,prevstateno != [5100,5299]
trigger1	=	p2statetype != A
trigger1	=	p2statetype != L
trigger1	=	p2bodydist x <= 13*2
trigger1	=	 fvar(39) := ifelse(power>1000&&random<ceil(600*(power/powermax)),3000,1020)
trigger2	=	p2stateno != [5100,5299]
trigger2	=	helper(161616),fvar(10) != [1000,1019];not blacklisted
trigger2	=	helper(161616),fvar(11) != [1000,1019];not blacklisted
trigger2	=	helper(161616),fvar(12) != [1000,1019];not blacklisted
trigger2	=	helper(161616),fvar(13) != [1000,1019];not blacklisted
trigger2	=	p2statetype = A
trigger2	=	enemynear,vel y = [-5,5]
trigger2	=	enemynear,pos y <= const(size.mid.pos.y)
trigger2	=	p2bodydist y <= const(size.head.pos.y)
trigger2	=	p2bodydist x <= 40*2
trigger2	=	 fvar(39) := 1010
trigger3	=	(helper(161616),fvar(10) != [1100,1119])||!p2movetype = A;not blacklisted
trigger3	=	(helper(161616),fvar(11) != [1100,1119])||!p2movetype = A;not blacklisted
trigger3	=	(helper(161616),fvar(12) != [1100,1119])||!p2movetype = A;not blacklisted
trigger3	=	(helper(161616),fvar(13) != [1100,1119])||!p2movetype = A;not blacklisted
trigger3	=	enemynear,cond(ishelper,movetype != A,!numproj)
trigger3	=	!InGuardDist
trigger3	=	p2stateno != [5100,5299]
trigger3	=	random < cond(2**ailevel>128,128,2**ailevel)
trigger3	=	p2statetype != L
trigger3	=	p2bodydist y >= const(size.head.pos.y)
trigger3	=	p2bodydist x = [40*2,90*2]
trigger3	=	 fvar(39) := 1100
[state -1, Full AI Programming, Movement & Guard]
Type = Null
IgnoreHitPause = 1
triggerall	=	numenemy
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	alive           ;Only when alive
TriggerAll	=	(AILevel) && !fvar(39)    ;AI only
triggerall	=	ctrl
trigger1	=	random <= enemynear,time ** 2
trigger1	=	abs(enemynear,animtime-enemynear,time) >= 30
trigger1	=	p2bodydist x > 25*2
trigger1	=	p2movetype = A
trigger1	=	p2statetype != A
trigger1	=	 fvar(39) := 40
trigger2	=	stateno != [120,159]
trigger2	=	movetype != A
trigger2	=	InGuardDist
trigger2	=	 fvar(39) := 120


[state -1, Full AI Programming, Combo Specific]
Type = Null
IgnoreHitPause = 1
triggerall	=	 !fvar(39)    ;AI only
TriggerAll	=	(AILevel) 
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	numenemy
triggerall	=	alive           ;Only when alive
triggerall	=	!InGuardDist         ;Not within guard distance
triggerall	=	NumTarget
Trigger1	=	var(59) = 1 || var(59) = 11 || var(59) = 9                     ;combo condition
trigger1	=	movecontact = 1
trigger1	=	(fvar(39) := 1030)
Trigger2	=	var(59) = 6||var(59) = 3
trigger2	=	p2stateno = 5101
trigger2	=	ctrl
trigger2	=	statetype != A
trigger2	=	(fvar(39) := 440)
Trigger3	=	var(59) = 5
trigger3	=	(fvar(39) := 1010)
Trigger4	=	var(59) = 4
trigger4	=	(fvar(39) := ifelse(random<200&&power>1000,3000,1020))
Trigger5	=	var(59) = 2
trigger5	=	(fvar(39) := 3030)
Trigger6	=	var(59) = 8
trigger6	=	target,vel y > 5
Trigger6	=	ctrl
trigger6	=	statetype != A
trigger6	=	(fvar(39) := 1110-100*(random<400))
Trigger7	=	var(59) = 21                     ;combo condition
trigger7	=	movecontact = 1
trigger7	=	(fvar(39) := 1040)
Trigger8	=	var(59) = 22                     ;combo condition
trigger8	=	power > 500
trigger8	=	movecontact = 1
trigger8	=	(fvar(39) := 6060)
Trigger9	=	var(59) = 22                     ;combo condition
trigger9	=	ctrl
trigger9	=	statetype != A
trigger9	=	(fvar(39) := ifelse(random<200&&power>1000,3000,1020))
Trigger10	=	stateno = 400||stateno=430||stateno = 230                     ;combo condition
Trigger10	=	movehit = 1                    ;combo condition
trigger10	=	(fvar(39) := 210+230*(p2bodydist x >= 2*20))
[state -1, Full AI Programming, Standard]
Type = Null
IgnoreHitPause = 1
triggerall	=	!InGuardDist         ;Not within guard distance
triggerall	=	!NumTarget         ;Not within guard distance
triggerall	=	numenemy
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	alive           ;Only when alive
TriggerAll	=	(AILevel) && !fvar(39)    ;AI only
triggerall	=	stateno != [120,159]
Triggerall	=	Ctrl                   ;while having control

trigger1	=	random<200
trigger1	=	p2movetype = I
trigger1	=	p2statetype != A
Trigger1	=	P2BodyDist X=[0,2*110]  ;Horizontal distance (maximum range)

trigger2	=	gametime%(11-ailevel) = 1 || ailevel>5 && p2movetype = h
trigger2	=	p2statetype != A
trigger2	=	p2statetype!=L         ;standard state conditions
Trigger2	=	P2BodyDist X=[0,2*75]  ;Horizontal distance (maximum range)
Trigger2	=	StateType != A	;Set for appropriate StateType

trigger3	=	gametime%(11-ailevel) = 1
trigger3	=	enemynear,vel y > -4 ;enemy jump-in conditions
trigger3	=	p2movetype != H
trigger3	=	p2statetype = A
Trigger3	=	P2BodyDist Y>=const(size.mid.pos.y)-40   ;vertical distance (anti-air situations, aim for the general vicinity of the attack's hitbox)
trigger3	=	P2BodyDist X=[-10*2,30*2]

trigger4	=	gametime%(15-ailevel) = 1
trigger4	=	p2movetype = I
trigger4	=	p2statetype != L
trigger4	=	p2bodydist y >= const(size.head.pos.y)
Trigger4	=	p2bodydist x > 2*120
trigger5	=	gametime%(21-ailevel) = 1
trigger5	=	p2movetype = I
trigger5	=	p2statetype != L
Trigger5	=	p2bodydist x <= 2*50
Trigger5	=	backedgedist  >= 2*50

trigger6	=	vel y = [-3,1]
trigger6	=	p2statetype != L
Trigger6	=	p2bodydist x <= 2*60
trigger6	=	statetype = A

trigger7	=	p2statetype = A
trigger7	=	p2bodydist y = [const(size.mid.pos.y),-const(size.mid.pos.y)]
Trigger7	=	p2bodydist x <= 2*60
trigger7	=	statetype = A

trigger8	=	gametime%(15-ailevel) = 1
trigger8	=	p2movetype = I
trigger8	=	p2statetype != L
trigger8	=	p2bodydist y >= const(size.head.pos.y)
Trigger8	=	p2bodydist x = [2*60,2*105]

;-------------------------------------------------
trigger1	=	(fvar(39) := 430)

trigger2	=	(fvar(39) := ifelse(p2bodydist x <= 2 * 22&&p2statetype!=C, 210,440))

trigger3	=	(fvar(39) := 215)

trigger4	=	(fvar(39) := 100)

trigger5	=	(fvar(39) := 105)

trigger6	=	(fvar(39) := 640)

trigger7	=	(fvar(39) := 610)

trigger8	=	(fvar(39) := 1040+60*(random<500))
;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
[State -1,Stop Jump]
type = ChangeState
value = 0
ctrl = 1
triggerall = AILevel
triggerall = stateno = 40
triggerall = fvar(39) != 40
triggerall = fvar(38) != 40
trigger1 = time = 0

;Burning Impulse (Hyper)
[State -1, Burning Impulse (Hyper)]
type = ChangeState
value = 3050
triggerall = fvar(39) = 3050
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Nonpleasant Conversation (Hyper)
[State -1, Nonpleasant Conversation (Hyper)]
type = ChangeState
value = 3030
triggerall = fvar(39) = 3030
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Burning Leg Lariat (Hyper)
[State -1, Burning Leg Lariat (Hyper)]
type = ChangeState
value = 3020
triggerall = fvar(39) = 3020
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Final Kotobuki Buster (Hyper)
[State -1, Final Kotobuki Buster (Hyper)]
type = ChangeState
value = 3000
triggerall = fvar(39) = 3000
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kotobuki Buster (Strong)
[State -1, Kotobuki Buster AI]
type = ChangeState
value = 1020
triggerall = fvar(39) = 1020
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Kotobuki Smash (EX)
[State -1, Kotobuki Smash (EX)]
type = ChangeState
value = 1050
triggerall = fvar(39) = 1050
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Kotobuki Smash (Light)
[State -1, Kotobuki Smash (Light)]
type = ChangeState
value = 1030
triggerall = fvar(39) = 1030
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Kotobuki Smash (Strong)
[State -1, Kotobuki Smash (Strong)]
type = ChangeState
value = 1040
triggerall = fvar(39) = 1040
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sky Brainbuster (Light)
[State -1, Aerial Brainbuster (Light)]
type = ChangeState
value = 1000
triggerall = fvar(39) = 1000
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sky Brainbuster (Strong)
[State -1, Aerial Brainbuster (Strong)]
type = ChangeState
value = 1010
triggerall = fvar(39) = 1010
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Leg Lariat (Light)
[State -1, Leg Lariat (EX)]
type = ChangeState
value = 1150
triggerall = fvar(39) = 1150
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Leg Lariat (Light)
[State -1, Leg Lariat (Light)]
type = ChangeState
value = 1130
triggerall = fvar(39) = 1130
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Leg Lariat (Strong)
[State -1, Leg Lariat (Strong)]
type = ChangeState
value = 1140
triggerall = fvar(39) = 1140
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sharan La Presse (Light)
[State -1, Sharan La Presse (Light)]
type = ChangeState
value = 1100
triggerall = fvar(39) = 1100
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sharan La Presse (Strong)
[State -1, Sharan La Presse (Strong)]
type = ChangeState
value = 1110
triggerall = fvar(39) = 1110
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = fvar(39) = 100
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = fvar(39) = 105
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = fvar(39) = 800
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Double Palm
[State -1, Stand Double Palm]
type = ChangeState
value = 205
triggerall = fvar(39) = 205
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 205 
trigger2 = time > 40

;---------------------------------------------------------------------------
;Stand Light Palm
[State -1, Stand Light Palm]
type = ChangeState
value = 200
triggerall = fvar(39) = 200
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Palm]
type = ChangeState
value = 210
triggerall = fvar(39) = 210
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Standing Double Fists
[State -1, Standing Double Fists]
type = ChangeState
value = 215
triggerall = fvar(39) = 215
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = fvar(39) = 230
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 12

;---------------------------------------------------------------------------
;Standing Strong Kmee
[State -1, Standing Strong Kmee]
type = ChangeState
value = 240
triggerall = fvar(39) = 240
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = fvar(39) = 195
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = fvar(39) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = fvar(39) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno  = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = fvar(39) = 430
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Slide Kick]
type = ChangeState
value = 440
triggerall = fvar(39) = 440
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = fvar(39) = 600
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = time > 12

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = fvar(39) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = fvar(39) = 630
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 630
trigger2 = time > 15

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = fvar(39) = 640
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6060+(statetype = S)
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = fvar(39) = 6060 && power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1110])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit
;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6062
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = fvar(39) = 6060 && power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1110])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Air)
[State -1, |Dizzy Guard Cancel Air|]
type = ChangeState
value = 6070
triggerall =  movetype = H
triggerall = statetype = A
triggerall = fvar(39) = 6070 && power > 1000
trigger1 = stateno = 154

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Stand)
[State -1, |Dizzy Guard Cancel Stand|]
type = ChangeState
value = 6071
triggerall =  movetype = H
triggerall = statetype = S
triggerall = fvar(39) = 6070 && power > 1000
trigger1 = stateno = 150

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Crouch)
[State -1, |Dizzy Guard Cancel Crouch|]
type = ChangeState
value = 6072
triggerall =  movetype = H
triggerall = statetype = C
triggerall = fvar(39) = 6070 && power > 1000
trigger1 = stateno = 152
[State -1,Jump]
type = ChangeState
value = 40
triggerall = AILevel
triggerall = fvar(39) = 40
trigger1 = ctrl
trigger1 = statetype != A
[State -1,Stop Jump]
type = ChangeState
value = 120
triggerall = AILevel
triggerall = fvar(39) = 120
trigger1 = ctrl

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Burning Impulse (Hyper)
[State -1, Burning Impulse (Hyper)]
type = ChangeState
value = 3050
TriggerAll = !AILevel
triggerall = command = "BurningImpulse"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Nonpleasant Conversation (Hyper)
[State -1, Nonpleasant Conversation (Hyper)]
type = ChangeState
value = 3030
TriggerAll = !AILevel
triggerall = command = "KotobukiSlam"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Burning Leg Lariat (Hyper)
[State -1, Burning Leg Lariat (Hyper)]
type = ChangeState
value = 3020
TriggerAll = !AILevel
triggerall = command = "BurningLegLariat"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Final Kotobuki Buster (Hyper)
[State -1, Final Kotobuki Buster (Hyper)]
type = ChangeState
value = 3000
TriggerAll = !AILevel
triggerall = command = "FinalKotobukiBuster"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Kotobuki Buster (Light)
[State -1, Kotobuki Buster (Light)]
type = ChangeState
value = 1020
TriggerAll = !AILevel
triggerall = command = "HCBF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Kotobuki Buster (Strong)
[State -1, Kotobuki Buster (Strong)]
type = ChangeState
value = 1020
TriggerAll = !AILevel
triggerall = command = "HCBF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Kotobuki Smash (EX)
[State -1, Kotobuki Smash (EX)]
type = ChangeState
value = 1050
TriggerAll = !AILevel
triggerall = command = "QCB_xy"
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Kotobuki Smash (Light)
[State -1, Kotobuki Smash (Light)]
type = ChangeState
value = 1030
TriggerAll = !AILevel
triggerall = command = "QCB_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Kotobuki Smash (Strong)
[State -1, Kotobuki Smash (Strong)]
type = ChangeState
value = 1040
TriggerAll = !AILevel
triggerall = command = "QCB_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sky Brainbuster (Light)
[State -1, Aerial Brainbuster (Light)]
type = ChangeState
value = 1000
TriggerAll = !AILevel
triggerall = command = "FDF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sky Brainbuster (Strong)
[State -1, Aerial Brainbuster (Strong)]
type = ChangeState
value = 1010
TriggerAll = !AILevel
triggerall = command = "FDF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Leg Lariat (Light)
[State -1, Leg Lariat (EX)]
type = ChangeState
value = 1150
TriggerAll = !AILevel
triggerall = command = "QCB_ab"
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Leg Lariat (Light)
[State -1, Leg Lariat (Light)]
type = ChangeState
value = 1130
TriggerAll = !AILevel
triggerall = command = "QCB_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Leg Lariat (Strong)
[State -1, Leg Lariat (Strong)]
type = ChangeState
value = 1140
TriggerAll = !AILevel
triggerall = command = "QCB_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sharan La Presse (Light)
[State -1, Sharan La Presse (Light)]
type = ChangeState
value = 1100
TriggerAll = !AILevel
triggerall = command = "HCF_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sharan La Presse (Strong)
[State -1, Sharan La Presse (Strong)]
type = ChangeState
value = 1110
TriggerAll = !AILevel
triggerall = command = "HCF_b"
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
TriggerAll = !AILevel
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
TriggerAll = !AILevel
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
TriggerAll = !AILevel
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 6
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Double Palm
[State -1, Stand Double Palm]
type = ChangeState
value = 205
TriggerAll = !AILevel
triggerall = command = "x"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 205 
trigger2 = time > 40

;---------------------------------------------------------------------------
;Stand Light Palm
[State -1, Stand Light Palm]
type = ChangeState
value = 200
TriggerAll = !AILevel
triggerall = command = "x"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 12

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Palm]
type = ChangeState
value = 210
TriggerAll = !AILevel
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Standing Double Fists
[State -1, Standing Double Fists]
type = ChangeState
value = 215
TriggerAll = !AILevel
triggerall = command = "holdfwd" && command = "holddown" && command = "y"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
TriggerAll = !AILevel
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 12

;---------------------------------------------------------------------------
;Standing Strong Kmee
[State -1, Standing Strong Kmee]
type = ChangeState
value = 240
TriggerAll = !AILevel
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
TriggerAll = !AILevel
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
TriggerAll = !AILevel
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
TriggerAll = !AILevel
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno  = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
TriggerAll = !AILevel
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Slide Kick]
type = ChangeState
value = 440
TriggerAll = !AILevel
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 205 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
TriggerAll = !AILevel
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = time > 12

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
TriggerAll = !AILevel
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
TriggerAll = !AILevel
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 630
trigger2 = time > 15

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
TriggerAll = !AILevel
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6060+(statetype = S)
TriggerAll = !AILevel
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1110])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit
;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6062
TriggerAll = !AILevel
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = command = "c" && power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1130,1141]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1110])
trigger2 = movehit
trigger3 = (stateno = [1030,1041])
trigger3 = movehit

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Air)
[State -1, |Dizzy Guard Cancel Air|]
type = ChangeState
value = 6070
TriggerAll = !AILevel
triggerall =  movetype = H
triggerall = statetype = A
triggerall = command = "z" && power > 1000
trigger1 = stateno = 154

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Stand)
[State -1, |Dizzy Guard Cancel Stand|]
type = ChangeState
value = 6071
TriggerAll = !AILevel
triggerall =  movetype = H
triggerall = statetype = S
triggerall = command = "z" && power > 1000
trigger1 = stateno = 150

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Crouch)
[State -1, |Dizzy Guard Cancel Crouch|]
type = ChangeState
value = 6072
TriggerAll = !AILevel
triggerall =  movetype = H
triggerall = statetype = C
triggerall = command = "z" && power > 1000
trigger1 = stateno = 152

;---------------------------------------------------------------------------